@@ -58,6 +58,27 @@ This option enables RSA keys initialize
 
 Default: off
 
+=head2 config_opts
+
+    config_opts => { ... }
+
+This option sets L<WWW::Suffit::Plugin::ConfigGeneral> plugin options
+
+Default:
+
+    `noload => 1` if $self->configobj exists
+    `defaults => $self->config` if $self->config is not void
+
+=head2 syslog_opts
+
+    syslog_opts => { ... }
+
+This option sets L<WWW::Suffit::Plugin::Syslog> plugin options
+
+Default:
+
+    `enable => 1` if the `Log` config directive is "syslog"
+
 =head1 ATTRIBUTES
 
 This class implements the following attributes
@@ -104,6 +125,10 @@ This attribute performs set the log level
 
 Default: warn
 
+=head2 max_history_size
+
+Maximum number of logged messages to store in "history", defaults to 25
+
 =head2 moniker
 
 Project name in lowercase notation, project nickname, moniker.
@@ -151,9 +176,21 @@ List of trusted proxies
 
 Default: none
 
+=head2 server_addr
+
+Main listener address (host)
+
+Default: * (::0, 0:0:0:0)
+
+=head2 server_port
+
+Main listener port
+
+Default: 8080
+
 =head2 server_url
 
-Main listener URL.
+Main listener URL
 
 See ListenAddr and ListenPort configuration directives
 
@@ -231,7 +268,7 @@ See C<LICENSE> file and L<https://dev.perl.org/licenses/>
 
 =cut
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use Mojo::Base 'Mojolicious';
 
@@ -264,6 +301,8 @@ use constant {
 has 'project_name';         # Anonymous
 has 'project_version';      # 1.00
 has 'server_url';           # http://127.0.0.1:8080
+has 'server_addr';          # * (0.0.0.0)
+has 'server_port';          # 8080
 has 'debugmode';            # 0
 has 'loglevel' => 'warn';   # warn
 has 'configobj';            # Config::General object
@@ -276,6 +315,7 @@ has 'mysecret' => DEFAULT_SECRET; # Secret
 has 'private_key' => '';    # Private RSA key
 has 'public_key' => '';     # Public RSA key
 has 'trustedproxies' => sub { [grep {length} @{(shift->conf->list("/trustedproxy"))}] };
+has 'max_history_size' => MAX_HISTORY_SIZE;
 has 'cache' => sub { Mojo::Cache->new };
 
 sub raise {
@@ -290,19 +330,30 @@ sub startup {
     $self->project_name(ref($self)) unless defined $self->project_name;
     $self->raise("Incorrect `project_name`") unless $self->project_name;
     $self->raise("Incorrect `project_version`") unless $self->project_version;
-    $self->raise("The `configobj` must be Config::General object")
-        unless !$self->configobj or ref($self->configobj) eq 'Config::General';
-    $self->config($self->configobj->getall) if $self->configobj; # Set config hash
     unshift @{$self->plugins->namespaces}, 'WWW::Suffit::Plugin'; # Add another namespace to load plugins from
     my $all_features = is_true_flag($opts->{all_features}); # on/off
 
+    # ConfigGeneral
+    my $config_opts = as_hash_ref($opts->{config_opts}) || {};
+    $self->raise("The `configobj` must be Config::General object")
+        unless !$self->configobj or ref($self->configobj) eq 'Config::General';
+    $self->config($self->configobj->getall) if $self->configobj; # Set config hash if configobj exist
+    unless (exists($config_opts->{noload})) { $config_opts->{noload} = $self->configobj ? 1 : 0 }
+    unless (exists($config_opts->{defaults})) { $config_opts->{defaults} = as_hash_ref($self->config) }
+    $self->plugin('ConfigGeneral' => $config_opts);
+
+    # Syslog
+    my $syslog_opts = as_hash_ref($opts->{syslog_opts}) || {};
+    my $syslogen = ($self->conf->latest('/log') && $self->conf->latest('/log') =~ /syslog/i) ? 1 : 0;
+    unless (exists($syslog_opts->{enable})) { $syslog_opts->{enable} = $syslogen };
+    $self->plugin('Syslog' => $syslog_opts);
+
     # Plugins
-    $self->plugin('ConfigGeneral' => {noload => $self->configobj ? 1 : 0, defaults => as_hash_ref($self->config)});
     $self->plugin('CommonHelpers');
-    $self->plugin('Syslog') if $self->conf->latest('/log') && $self->conf->latest('/log') =~ /syslog/i;
 
     # Logging
-    $self->log->level($self->loglevel || ($self->debugmode ? "debug" : "warn"))->max_history_size(MAX_HISTORY_SIZE);
+    $self->log->level($self->loglevel || ($self->debugmode ? "debug" : "warn"))
+        ->max_history_size($self->max_history_size || MAX_HISTORY_SIZE);
     $self->log->path($self->logfile) if $self->logfile;
 
     # Helpers
@@ -413,8 +464,10 @@ sub listeners {
 
     # Master URL
     my $url = Mojo::URL->new($self->server_url || DEFAULT_SERVER_URL);
-    $url->host($self->conf->latest("/listenaddr") || DEFAULT_SERVER_ADDR);
-    $url->port($self->conf->latest("/listenport") || DEFAULT_SERVER_PORT);
+    my $host = $self->server_url ? $url->host : ($self->server_addr || DEFAULT_SERVER_ADDR);
+    my $port = $self->server_url ? $url->port : ($self->server_port || DEFAULT_SERVER_PORT);
+    $url->host($self->conf->latest("/listenaddr") || $host);
+    $url->port($self->conf->latest("/listenport") || $port);
 
     # Added TLS parameters
     if (is_true_flag($self->conf->latest("/tls"))) {
